package cz.zweistein.df.soundsense.config;

import java.util.LinkedList;
import java.util.Queue;

public class ContinuousEvent {
	
	private String event;
	
	private long sustainedTime;
	private long sustainedCount;
	
	private long duration;
	
	private Queue<Long> eventHistory;
	private boolean goingOn;

	public ContinuousEvent(String event, long sustainedTime, long sustainedCount, long duration) {
		this.event = event;
		this.sustainedTime = sustainedTime;
		this.sustainedCount = sustainedCount;
		this.duration = duration;
		
		this.eventHistory = new LinkedList<Long>();
		this.goingOn = false;
	}

	public String getEvent() {
		return this.event;
	}

	public long getSustainedTime() {
		return this.sustainedTime;
	}

	public long getSustainedCount() {
		return this.sustainedCount;
	}
	
	public Queue<Long> getEventHistory() {
		return this.eventHistory;
	}
	
	public long getDuration() {
		return this.duration;
	}

	public synchronized boolean hitEvent() {
		this.eventHistory.add(System.currentTimeMillis());
		
		// remove entries too old for consideration
		while (!this.eventHistory.isEmpty() && (this.eventHistory.peek() < (System.currentTimeMillis() - this.sustainedTime))) {
			this.eventHistory.remove();
		}
		
		// turn on continuous event if we are within 
		if (this.eventHistory.size() >= this.sustainedCount) {
			this.goingOn = true;
		}
		
		return this.goingOn;
		
	}

}
